@@ -61,7 +61,7 @@ void onlinehelp(int standalone,int context)
     "D,F Transpose octave down/up",
     "G,B Copy,paste effects",
     "H Make hifi vib/portaspeed",
-    "I Invert selection/pattern",
+    "FN+g Invert selection/pattern",
     "J,K Join/split pattern",
     "L Mark/unmark whole pattern",
     "M,N Choose highlighting step",
