@@ -945,7 +945,7 @@ void generalcommands(void)
 	    if (!shiftpressed)
 		quit();
 	    else
-	        clear();
+		clear();
 	}
     break;
 
@@ -1296,7 +1296,7 @@ void editadsr(void)
       case KEY_U:
       if (!shiftpressed) break;
 
-      case KEY_ESC:
+//      case KEY_ESC:
       case KEY_ENTER:
       case KEY_TAB:
       eamode = 0;
@@ -1305,7 +1305,15 @@ void editadsr(void)
       return;
 
       case KEY_BACKSPACE:
-      if (!eacolumn && !fnpressed) break;
+      if (fnpressed) {
+        eamode = 0;
+        key = 0;
+        rawkey = 0;
+        return;
+      } else {
+        if (!eacolumn) break;
+      }
+
       case KEY_LEFT:
       eacolumn--;
       break;
