@@ -96,7 +96,7 @@ void patterncommands(void)
     }
 
     if (newnote > LASTNOTE) newnote = -1;
-    if ((rawkey == 0x08) && (!epcolumn)) newnote = REST;
+    if ((rawkey == 0x08) && (!epcolumn) && (!fnpressed)) newnote = REST;
     if ((rawkey == 0x14) && (!epcolumn)) newnote = KEYOFF;
     if (rawkey == KEY_ENTER)
     {
@@ -367,10 +367,6 @@ void patterncommands(void)
     }
     break;
 
-
-
-    break;
-
     case KEY_Z:
     if (shiftpressed)
     {
@@ -861,7 +857,6 @@ void patterncommands(void)
 	    mutechannel(2);
 	}
     }
-
     break;
 
     case KEY_V:
@@ -879,39 +874,6 @@ void patterncommands(void)
     }
     break;
 
-    case KEY_INS:
-    if (epmarkchn == epchn) epmarkchn = -1;
-    if ((pattlen[epnum[epchn]]-eppos)*4-4 >= 0)
-    {
-      memmove(&pattern[epnum[epchn]][eppos*4+4],
-        &pattern[epnum[epchn]][eppos*4],
-        (pattlen[epnum[epchn]]-eppos)*4-4);
-      pattern[epnum[epchn]][eppos*4] = REST;
-      pattern[epnum[epchn]][eppos*4+1] = 0x00;
-      pattern[epnum[epchn]][eppos*4+2] = 0x00;
-      pattern[epnum[epchn]][eppos*4+3] = 0x00;
-    }
-    else
-    {
-      if (eppos == pattlen[epnum[epchn]])
-      {
-        if (pattlen[epnum[epchn]] < MAX_PATTROWS)
-        {
-          pattern[epnum[epchn]][eppos*4] = REST;
-          pattern[epnum[epchn]][eppos*4+1] = 0x00;
-          pattern[epnum[epchn]][eppos*4+2] = 0x00;
-          pattern[epnum[epchn]][eppos*4+3] = 0x00;
-          pattern[epnum[epchn]][eppos*4+4] = ENDPATT;
-          pattern[epnum[epchn]][eppos*4+5] = 0x00;
-          pattern[epnum[epchn]][eppos*4+6] = 0x00;
-          pattern[epnum[epchn]][eppos*4+7] = 0x00;
-          countthispattern();
-          eppos = pattlen[epnum[epchn]];
-        }
-      }
-    }
-    break;
-
     case KEY_SPACE:
     if (!shiftpressed)
       recordmode ^= 1;
